def tokenize(tokenizer, examples, columns_map, *args, **kwargs):
    for new_name, old_name in columns_map.items():
        if type(examples[old_name][0]) != str:
            examples[old_name] = [str(x) for x in examples[old_name]]
        examples[new_name] = tokenizer(examples[old_name], *args, **kwargs)["input_ids"]
    return examples


def advance_tokenize(tokenizer, dataset, columns_map, *args, **kwargs):
    dataset = dataset.map(
        lambda examples: tokenize(
            tokenizer, examples, columns_map, *args, **kwargs
        ),
        batched=True,
        num_proc=4,
        desc="Running tokenizer on dataset",
    )
    return dataset
    


from dingtalkchatbot.chatbot import DingtalkChatbot
import os
from lazydl.utils.log import Logger
import psutil

log = Logger(__name__)

def notice(msg: str = "", warning=False, access_token="", secret=""):
    """钉钉消息通知
    
    """
    access_token = os.environ.get('DINGDING_ACCESS_TOKEN', "") if access_token == "" else access_token
    secret = os.environ.get('DINGDING_SECRET', "") if secret == "" else secret
    if access_token == "" or secret == "":
        log.warning("未设置钉钉Token，无法发送消息: " + msg)
        return
    
    pid = os.getpid()
    proctitle = psutil.Process(pid).name()
    if warning:
        msg = f"⚠️\n{msg}\n\n👾进程ID: {pid}\n👾进程名: {proctitle}"
    else:
        msg = f"🪼\n{msg}\n\n👾进程ID: {pid}\n👾进程名: {proctitle}"
    
    # WebHook地址
    webhook = f'https://oapi.dingtalk.com/robot/send?access_token={access_token}'
    xiaoding = DingtalkChatbot(webhook, secret=secret, pc_slide=True)
    # Text消息@所有人
    xiaoding.send_text(msg=msg)
    log.info(f"已将下面通知发送到钉钉！")
    log.info(msg)